@@ -1,8 +1,6 @@
 """Echo task for ScriptEngine."""
 
-from scriptengine.tasks.base import Task
-from scriptengine.tasks.base.timing import timed_runner
-
+from scriptengine.tasks.core import Task, timed_runner
 from scriptengine.helpers import terminal_colors as tc
 
 
