@@ -3,8 +3,7 @@
 import os
 import fnmatch
 
-from scriptengine.tasks.base import Task
-from scriptengine.tasks.base.timing import timed_runner
+from scriptengine.tasks.core import Task, timed_runner
 from scriptengine.exceptions import ScriptEngineTaskArgumentInvalidError
 
 
