@@ -2,8 +2,7 @@
 
 import os
 
-from scriptengine.tasks.base import Task
-from scriptengine.tasks.base.timing import timed_runner
+from scriptengine.tasks.core import Task, timed_runner
 
 
 class Getenv(Task):
